@@ -10,13 +10,13 @@ use File::Path qw(mkpath);
 use File::Slurp::Tiny qw(read_file write_file);
 
 use File::Spec;
-use Guard;
+use Scope::Guard qw(guard);
 use Path::Tiny 0.098 qw(cwd path tempdir);
 use Try::Tiny;
 
 use Exporter qw(import);
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 our @EXPORT_OK = qw(can_load pushd tempdir_simple dirname mkpath read_file write_file);
 
